@@ -1,15 +1,17 @@
 import os
 import requests
 import logging
-
+import configparser
 
 logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
 
 class ManageFiles():
     def __init__(self):
-
-        FMS_HOST = os.getenv('FMS_HOST') or '10.1.0.5'
-        FMS_PORT = os.getenv('FMS_PORT') or '8007'
+        config = configparser.ConfigParser()
+        config.sections()
+        config.read("broker_config.ini")
+        FMS_HOST = config.get('FMSConfig','FMS_HOST') or '10.1.0.5'
+        FMS_PORT = config.get('FMSConfig','FMS_HOST') or '8007'
         self.fms_host = FMS_HOST
         self.fms_port = FMS_PORT
         self.fms_url = f"{self.fms_host}:{self.fms_port}"
@@ -25,7 +27,7 @@ class ManageFiles():
                 for chunk in response.iter_content(chunk_size=1024): 
                     file.write(chunk)
             response.close()
-        logging.info(f"File Downloaded Successfully {file_key}.{ext}")
+        logging.warning(f"File Downloaded Successfully {file_key}.{ext}")
         return f"File Donwloaded Successfully {file_key}.{ext}"
 
     def upload_file(self, file_key, ext, location, group, created_by):
@@ -38,14 +40,14 @@ class ManageFiles():
             with file_request.post(url, file, headers=headers, stream=True) as req:
                 req.raise_for_status()
         file_request.close()
-        logging.info(f"File Uploaded Successfully {file_key}.{ext}")
+        logging.warning(f"File Uploaded Successfully {file_key}.{ext}")
         return f"File Uploaded Successfully {file_key}.{ext}"
 
     def delete_file(self, file_key, ext, location): 
         os.remove(os.path.join(self.base_location, f"{location}/{file_key}.{ext}"))
-        logging.info(f"File Deleted Successfully {file_key}.{ext}")
+        logging.warning(f"File Deleted Successfully {file_key}.{ext}")
         return f"File Deleted Successfully {file_key}.{ext}"
 
-
+cls = ManageFiles()
 
 
